API docs for “spamfighter.rules.model.modelClassify”

# Class s.r.m.modelClassify(ModelRule):

Part of spamfighter.rules.model View Source View In Hierarchy

Классификация сообщения по модели: истинно, если модель сообщает, что сообщение относится к классу *плохих*.

Method | analyze | Анализ сообщения.

Inherited from ModelRule:

Method | __init__ | Конструктор.

def analyze(self, domain, message, **kwargs): (source)
overrides spamfighter.rules.model.ModelRule.analyze
Анализ сообщения.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения, содержащего текст (type: `str` )